package
Version:
v0.0.1-draft
Opens a new window with list of versions in this module.
Published: Sep 8, 2022
License: MIT
Opens a new window with license information.
Imports: 5
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type DataMapper struct {
}
DataMapper 数据映射工具
Mapper 数据映射工具
替换原始数据,用于统一输出数据格式
Source Files
¶
Click to show internal directories.
Click to hide internal directories.