Documentation
¶
Index ¶
Constants ¶
const ( DBFormat = "plain" DBExt = ".txt" MetaPrefix = "# Meta: " FieldSep = "," )
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Reader ¶
type Reader struct {
// contains filtered or unexported fields
}
Reader is a structure that provides functionalities to read from Plain Text.
func (*Reader) Find ¶
Find retrieves IP information based on the given IP address. FIXME this method returns the next available IP info sequentially from the file.
type Writer ¶
type Writer struct {
// contains filtered or unexported fields
}
Writer provides functionalities to write IP data into plain text format.
func NewWriter ¶
NewWriter initializes a new Writer instance for writing IP data in plain text format. If the io.Writer is not nil, it will directly write data into it.
type WriterOption ¶
WriterOption provides options for the Writer.
Click to show internal directories.
Click to hide internal directories.